summaryrefslogtreecommitdiff
path: root/src/xkbcomp/keymap.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/xkbcomp/keymap.c')
-rw-r--r--src/xkbcomp/keymap.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/xkbcomp/keymap.c b/src/xkbcomp/keymap.c
index 78ba966..cd1f79c 100644
--- a/src/xkbcomp/keymap.c
+++ b/src/xkbcomp/keymap.c
@@ -90,10 +90,10 @@ FindInterpForKey(struct xkb_keymap *keymap, const struct xkb_key *key,
/*
* There may be multiple matchings interprets; we should always return
* the most specific. Here we rely on compat.c to set up the
* sym_interpret array from the most specific to the least specific,
* such that when we find a match we return immediately.
*/
- darray_foreach(interp, keymap->sym_interpret) {
+ darray_foreach(interp, keymap->sym_interprets) {
xkb_mod_mask_t mods;
bool found;
@@ -90,10 +90,10 @@ FindInterpForKey(struct xkb_keymap *keymap, const struct xkb_key *key,
* There may be multiple matchings interprets; we should always return
* the most specific. Here we rely on compat.c to set up the
- * sym_interpret array from the most specific to the least specific,
+ * sym_interprets array from the most specific to the least specific,
* such that when we find a match we return immediately.
*/